grib2io.tables.section4_discipline2 API documentation

# grib2io.tables.section4_discipline2

View Source

      1table_4_2_2_0  = {
      2'0':['Land Cover (0=sea, 1=land)','Proportion','LAND'],
      3'1':['Surface Roughness','m','SFCR'],
      4'2':['Soil Temperature','K','TSOIL'],
      5'3':['Parameter deprecated - use another parameter instead.','unknown','unknown'],
      6'4':['Vegetation','%','VEG'],
      7'5':['Water Runoff','kg m-2','WATR'],
      8'6':['Evapotranspiration','kg-2 s-1','EVAPT'],
      9'7':['Model Terrain Height','m','MTERH'],
     10'8':['Land Use','See Table 4.212','LANDU'],
     11'9':['Volumetric Soil Moisture Content','Proportion','SOILW'],
     12'10':['Ground Heat Flux','W m-2','GFLUX'],
     13'11':['Moisture Availability','%','MSTAV'],
     14'12':['Exchange Coefficient','kg m-2 s-1','SFEXC'],
     15'13':['Plant Canopy Surface Water','kg m-2','CNWAT'],
     16'14':['Blackadars Mixing Length Scale','m','BMIXL'],
     17'15':['Canopy Conductance','m s-1','CCOND'],
     18'16':['Minimal Stomatal Resistance','s m-1','RSMIN'],
     19'17':['Wilting Point','Proportion','WILT'],
     20'18':['Solar parameter in canopy conductance','Proportion','RCS'],
     21'19':['Temperature parameter in canopy','Proportion','RCT'],
     22'20':['Humidity parameter in canopy conductance','Proportion','RCQ'],
     23'21':['Soil moisture parameter in canopy conductance','Proportion','RCSOL'],
     24'22':['Parameter deprecated - use another parameter instead.','unknown','unknown'],
     25'23':['Column-Integrated Soil Water','kg m-2','CISOILW'],
     26'24':['Heat Flux','W m-2','HFLUX'],
     27'25':['Volumetric Soil Moisture','m3 m-3','VSOILM'],
     28'26':['Wilting Point','kg m-3','WILT'],
     29'27':['Volumetric Wilting Point','m3 m-3','VWILTP'],
     30'28':['Leaf Area Index','Numeric','LEAINX'],
     31'29':['Evergreen Forest Cover','Proportion','EVGFC'],
     32'30':['Deciduous Forest Cover','Proportion','DECFC'],
     33'31':['Normalized Differential Vegetation Index (NDVI)','Numeric','NDVINX'],
     34'32':['Root Depth of Vegetation','m','RDVEG'],
     35'33':['Water Runoff and Drainage','kg m-2','WROD'],
     36'34':['Surface Water Runoff','kg m-2','SFCWRO'],
     37'35':['Tile Class','See Table 4.243','TCLASS'],
     38'36':['Tile Fraction','Proportion','TFRCT'],
     39'37':['Tile Percentage','%','TPERCT'],
     40'38':['Soil Volumetric Ice Content (Water Equivalent)','m3 m-3','SOILVIC'],
     41'39':['Evapotranspiration Rate','kg m-2 s-1','EVAPTRAT'],
     42'39-191':['Reserved','unknown','unknown'],
     43'192-254':['Reserved for Local Use','unknown','unknown'],
     44'192':['Volumetric Soil Moisture Content','Fraction','SOILW'],
     45'193':['Ground Heat Flux','W m-2','GFLUX'],
     46'194':['Moisture Availability','%','MSTAV'],
     47'195':['Exchange Coefficient','(kg m-3) (m s-1)','SFEXC'],
     48'196':['Plant Canopy Surface Water','kg m-2','CNWAT'],
     49'197':['Blackadar’s Mixing Length Scale','m','BMIXL'],
     50'198':['Vegetation Type','Integer (0-13)','VGTYP'],
     51'199':['Canopy Conductance','m s-1','CCOND'],
     52'200':['Minimal Stomatal Resistance','s m-1','RSMIN'],
     53'201':['Wilting Point','Fraction','WILT'],
     54'202':['Solar parameter in canopy conductance','Fraction','RCS'],
     55'203':['Temperature parameter in canopy conductance','Fraction','RCT'],
     56'204':['Humidity parameter in canopy conductance','Fraction','RCQ'],
     57'205':['Soil moisture parameter in canopy conductance','Fraction','RCSOL'],
     58'206':['Rate of water dropping from canopy to ground','unknown','RDRIP'],
     59'207':['Ice-free water surface','%','ICWAT'],
     60'208':['Surface exchange coefficients for T and Q divided by delta z','m s-1','AKHS'],
     61'209':['Surface exchange coefficients for U and V divided by delta z','m s-1','AKMS'],
     62'210':['Vegetation canopy temperature','K','VEGT'],
     63'211':['Surface water storage','Kg m-2','SSTOR'],
     64'212':['Liquid soil moisture content (non-frozen)','Kg m-2','LSOIL'],
     65'213':['Open water evaporation (standing water)','W m-2','EWATR'],
     66'214':['Groundwater recharge','Kg m-2','GWREC'],
     67'215':['Flood plain recharge','Kg m-2','QREC'],
     68'216':['Roughness length for heat','m','SFCRH'],
     69'217':['Normalized Difference Vegetation Index','unknown','NDVI'],
     70'218':['Land-sea coverage (nearest neighbor) [land=1,sea=0]','unknown','LANDN'],
     71'219':['Asymptotic mixing length scale','m','AMIXL'],
     72'220':['Water vapor added by precip assimilation','Kg m-2','WVINC'],
     73'221':['Water condensate added by precip assimilation','Kg m-2','WCINC'],
     74'222':['Water Vapor Flux Convergance (Vertical Int)','Kg m-2','WVCONV'],
     75'223':['Water Condensate Flux Convergance (Vertical Int)','Kg m-2','WCCONV'],
     76'224':['Water Vapor Zonal Flux (Vertical Int)','Kg m-2','WVUFLX'],
     77'225':['Water Vapor Meridional Flux (Vertical Int)','Kg m-2','WVVFLX'],
     78'226':['Water Condensate Zonal Flux (Vertical Int)','Kg m-2','WCUFLX'],
     79'227':['Water Condensate Meridional Flux (Vertical Int)','Kg m-2','WCVFLX'],
     80'228':['Aerodynamic conductance','m s-1','ACOND'],
     81'229':['Canopy water evaporation','W m-2','EVCW'],
     82'230':['Transpiration','W m-2','TRANS'],
     83'231':['Seasonally Minimum Green Vegetation Fraction (over 1-year period)','%','VEGMIN'],
     84'232':['Seasonally Maximum Green Vegetation Fraction (over 1-year period)','%','VEGMAX'],
     85'233':['Land Fraction','Fraction','LANDFRC'],
     86'234':['Lake Fraction','Fraction','LAKEFRC'],
     87'235':['Precipitation Advected Heat Flux','W m-2','PAHFLX'],
     88'236':['Water Storage in Aquifer','Kg m-2','WATERSA'],
     89'237':['Evaporation of Intercepted Water','Kg m-2','EIWATER'],
     90'238':['Plant Transpiration','Kg m-2','PLANTTR'],
     91'239':['Soil Surface Evaporation','Kg m-2','SOILSE'],
     92'255':['Missing','unknown','unknown'],
     93}
     94table_4_2_2_1  = {
     95'0-191':['Reserved','unknown','unknown'],
     96'192-254':['Reserved for Local Use','unknown','unknown'],
     97'192':['Cold Advisory for Newborn Livestock','unknown','CANL'],
     98'255':['Missing','unknown','unknown'],
     99}
    100table_4_2_2_3  = {
    101'0':['Soil Type','See Table 4.213','SOTYP'],
    102'1':['Upper Layer Soil Temperature','K','UPLST'],
    103'2':['Upper Layer Soil Moisture','kg m-3','UPLSM'],
    104'3':['Lower Layer Soil Moisture','kg m-3','LOWLSM'],
    105'4':['Bottom Layer Soil Temperature','K','BOTLST'],
    106'5':['Liquid Volumetric Soil Moisture (non-frozen)','Proportion','SOILL'],
    107'6':['Number of Soil Layers in Root Zone','Numeric','RLYRS'],
    108'7':['Transpiration Stress-onset (soil moisture)','Proportion','SMREF'],
    109'8':['Direct Evaporation Cease (soil moisture)','Proportion','SMDRY'],
    110'9':['Soil Porosity','Proportion','POROS'],
    111'10':['Liquid Volumetric Soil Moisture (Non-Frozen)','m3 m-3','LIQVSM'],
    112'11':['Volumetric Transpiration Stree-Onset(Soil Moisture)','m3 m-3','VOLTSO'],
    113'12':['Transpiration Stree-Onset(Soil Moisture)','kg m-3','TRANSO'],
    114'13':['Volumetric Direct Evaporation Cease(Soil Moisture)','m3 m-3','VOLDEC'],
    115'14':['Direct Evaporation Cease(Soil Moisture)','kg m-3','DIREC'],
    116'15':['Soil Porosity','m3 m-3','SOILP'],
    117'16':['Volumetric Saturation Of Soil Moisture','m3 m-3','VSOSM'],
    118'17':['Saturation Of Soil Moisture','kg m-3','SATOSM'],
    119'18':['Soil Temperature','K','SOILTMP'],
    120'19':['Soil Moisture','kg m-3','SOILMOI'],
    121'20':['Column-Integrated Soil Moisture','kg m-2','CISOILM'],
    122'21':['Soil Ice','kg m-3','SOILICE'],
    123'22':['Column-Integrated Soil Ice','kg m-2','CISICE'],
    124'23':['Liquid Water in Snow Pack','kg m-2','LWSNWP'],
    125'24':['Frost Index','kg day-1','FRSTINX'],
    126'25':['Snow Depth at Elevation Bands','kg m-2','SNWDEB'],
    127'26':['Soil Heat Flux','W m-2','SHFLX'],
    128'27':['Soil Depth','m','SOILDEP'],
    129'28-191':['Reserved','unknown','unknown'],
    130'192-254':['Reserved for Local Use','unknown','unknown'],
    131'192':['Liquid Volumetric Soil Moisture (non Frozen)','Proportion','SOILL'],
    132'193':['Number of Soil Layers in Root Zone','non-dim','RLYRS'],
    133'194':['Surface Slope Type','Index','SLTYP'],
    134'195':['Transpiration Stress-onset (soil moisture)','Proportion','SMREF'],
    135'196':['Direct Evaporation Cease (soil moisture)','Proportion','SMDRY'],
    136'197':['Soil Porosity','Proportion','POROS'],
    137'198':['Direct Evaporation from Bare Soil','W m-2','EVBS'],
    138'199':['Land Surface Precipitation Accumulation','kg m-2','LSPA'],
    139'200':['Bare Soil Surface Skin temperature','K','BARET'],
    140'201':['Average Surface Skin Temperature','K','AVSFT'],
    141'202':['Effective Radiative Skin Temperature','K','RADT'],
    142'203':['Field Capacity','Fraction','FLDCP'],
    143'204':['Soil Moisture Availability In The Top Soil Layer','%','MSTAV'],
    144'255':['Missing','unknown','unknown'],
    145}
    146table_4_2_2_4  = {
    147'0':['Fire Outlook','See Table 4.224','FIREOLK'],
    148'1':['Fire Outlook Due to Dry Thunderstorm','See Table 4.224','FIREODT'],
    149'2':['Haines Index','Numeric','HINDEX'],
    150'3':['Fire Burned Area','%','FBAREA'],
    151'4':['Fosberg Index','Numeric','FOSINDX'],
    152'5':['Fire Weath Index (Canadian Forest Service)','Numeric','FWINX'],
    153'6':['Fine Fuel Moisture Code (Canadian Forest Service)','Numeric','FFMCODE'],
    154'7':['Duff Moisture Code (Canadian Forest Service)','Numeric','DUFMCODE'],
    155'8':['Drought Code (Canadian Forest Service)','Numeric','DRTCODE'],
    156'9':['Initial Fire Spread Index (Canadian Forest Service)','Numeric','INFSINX'],
    157'10':['Fire Build Up Index (Canadian Forest Service)','Numeric','FBUPINX'],
    158'11':['Fire Daily Severity Rating (Canadian Forest Service)','Numeric','FDSRTE'],
    159'12-191':['Reserved','unknown','unknown'],
    160'192-254':['Reserved for Local Use','unknown','unknown'],
    161'255':['Missing','unknown','unknown'],
    162}
    163table_4_2_2_5  = {
    164'1':['Glacier Temperature','K','GLACTMP'],
    165'2-191':['Reserved','unknown','unknown'],
    166'192-254':['Reserved for Local Use','unknown','unknown'],
    167'255':['Missing','unknown','unknown'],
    168}